@@ -378,7 +378,8 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
 		AddRule ("reactant", RuleMayContain, "molecule");
 		AddRule ("reactant", RuleMayContain, "text");
-		AddRule ("mesomer", RuleMustContain, "molecule");
+		AddRule ("reactant", RuleMayContain, "mesomery");
+		AddRule ("mesomer", RuleMayContain, "molecule");
 		AddRule ("mesomer", RuleMustBeIn, "mesomery");
 		AddRule ("mesomery", RuleMustContain, "mesomer");
 		AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
@@ -386,7 +387,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		MechanismArrowType = AddType ("mechanism-arrow", CreateMechanismArrow);
 		MechanismStepType = AddType ("mechanism-step", CreateMechanismStep);
 		AddRule ("reaction-step", RuleMayContain, "mechanism-step");
-		AddRule ("mesomery", RuleMayContain, "mechanism-step");
+		AddRule ("mesomer", RuleMayContain, "mechanism-step");
 
 		// Create global signal ids
 		OnChangedSignal = Object::CreateNewSignalId ();
@@ -621,7 +622,9 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 	}
 	if (file_type < 0 || (!bSave && (file_type > CHEMISTRY))) {
 		char *unescaped = g_uri_unescape_string (filename, NULL);
-		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, unescaped);
+		char *mess = bSave?
+					 g_strdup_printf (_("Sorry, format %s not supported!\nFailed to save %s."), mime_type, unescaped):
+					 g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, unescaped);
 		g_free (unescaped);
 		GetCmdContext ()->Message (mess, CmdContext::SeverityError, true);
 		g_free (mess);
@@ -1040,13 +1043,8 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 	if (ui_description)
 		UiDescs.push_back (ui_description);
 	if (icons) {
-		GtkCssProvider *provider = gtk_css_provider_get_default ();
-		GtkStyleContext *ctxt = gtk_style_context_new ();
-		GtkWidgetPath *path = gtk_widget_path_new ();
-		gtk_widget_path_append_type (path, GTK_TYPE_BUTTON);
-		gtk_style_context_set_path (ctxt, path);
-		gtk_widget_path_free (path);
-		gtk_style_context_add_provider (ctxt, GTK_STYLE_PROVIDER (provider), 1);
+		GtkWidget *w = gtk_button_new ();
+		GtkStyleContext *ctxt = gtk_widget_get_style_context (w);
 		GtkIconSet *set;
 		GtkIconSource *src;
 		while (icons->name) {
@@ -1060,13 +1058,39 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 				gtk_icon_source_set_direction_wildcarded (src, true);
 
 				for (int c = 0; c < 5; c++) {
-				icon = gdk_pixbuf_copy (pixbuf);
-#if 0
+					GtkStateFlags state;
+					switch (c) {
+					default:
+					case 0:
+						state = GTK_STATE_FLAG_NORMAL;
+						break;
+					case 1:
+						state = GTK_STATE_FLAG_ACTIVE;
+						break;
+					case 2:
+						state = GTK_STATE_FLAG_PRELIGHT;
+						break;
+					case 3:
+						state = GTK_STATE_FLAG_SELECTED;
+						break;
+					case 4:
+						state = GTK_STATE_FLAG_INSENSITIVE;
+						break;
+					case 5:
+						state = GTK_STATE_FLAG_INCONSISTENT;
+						break;
+					case 6:
+						state = GTK_STATE_FLAG_FOCUSED;
+						break;
+					}
+					GdkRGBA rgba;
+					gtk_style_context_get_color (ctxt, state, &rgba);
+					icon = gdk_pixbuf_copy (pixbuf);
 					// set the pixbuf color to the corresponding style for the style
 					unsigned char red, blue, green;
-					red = m_Style->fg[c].red >> 8;
-					green = m_Style->fg[c].green >> 8;
-					blue = m_Style->fg[c].blue >> 8;
+					red = rgba.red * 255;
+					green = rgba.green * 255;
+					blue = rgba.blue * 255;
 					unsigned char *line, *cur;
 					line = gdk_pixbuf_get_pixels (icon);
 					int i, j, rows, cols, rowstride;
@@ -1083,7 +1107,6 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 							cur += 4;
 						}
 					}
-#endif
 					gtk_icon_source_set_pixbuf (src, icon);
 					gtk_icon_source_set_state (src, static_cast <GtkStateType> (c));
 					gtk_icon_set_add_source (set, src);	/* copies the src */
@@ -1148,6 +1171,7 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 			icons++;
 		}
 		g_object_unref (ctxt);
+		gtk_widget_destroy (w);
 	}
 }
 
