@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -42,12 +42,12 @@ static void on_space_toggled (gcpGroupDlg *dlg)
 }
 
 gcpGroupDlg::gcpGroupDlg (gcp::Document *Doc, gcpGroup *group):
-	gcugtk::Dialog (Doc->GetApplication (), UIDIR"/group.ui", "group", GETTEXT_PACKAGE, Doc)
+	gcugtk::Dialog (Doc->GetApplication (), UIDIR"/group.ui", "group", GETTEXT_PACKAGE, (group)? static_cast < DialogOwner * > (group): static_cast < DialogOwner * > (Doc))
 {
 	m_Group = group;
 	m_Doc = Doc;
 	m_Data = (gcp::WidgetData*) g_object_get_data (G_OBJECT (Doc->GetWidget ()), "data");
-	align_box = GTK_COMBO_BOX (GetWidget ("align_type"));
+	align_box = GTK_COMBO_BOX (GetWidget ("align-type"));
 	align_btn = GTK_TOGGLE_BUTTON (GetWidget ("align_btn"));
 	group_btn = GTK_TOGGLE_BUTTON (GetWidget ("group_btn"));
 	space_btn = GTK_TOGGLE_BUTTON (GetWidget ("space"));
@@ -79,6 +79,7 @@ gcpGroupDlg::gcpGroupDlg (gcp::Document *Doc, gcpGroup *group):
 	}
 	g_signal_connect_swapped (align_btn, "toggled", G_CALLBACK (on_align_toggled), this);
 	g_signal_connect_swapped (space_btn, "toggled", G_CALLBACK (on_space_toggled), this);
+	gtk_widget_show_all (GTK_WIDGET (dialog));
 }
 
 gcpGroupDlg::~gcpGroupDlg ()
@@ -90,6 +91,12 @@ void gcpGroupDlg::SetAlignType (gcpAlignType type)
 	gtk_combo_box_set_active (align_box, type);
 }
 
+static bool delete_cb (gcpGroup *group)
+{
+	delete group;
+	return false;
+}
+
 bool gcpGroupDlg::Apply ()
 {
 	std::set < Object  *>::iterator i, end;
@@ -107,7 +114,7 @@ bool gcpGroupDlg::Apply ()
 			pOp->AddObject (*i, 0);
 	}
 
-	if (!m_Group) {
+	if (group && !m_Group) {
 		m_Group = new gcpGroup ();
 		m_Group->SetParent (m_Doc);
 		for (i = m_Data->SelectedObjects.begin (); i!= end; i++)
@@ -137,7 +144,8 @@ bool gcpGroupDlg::Apply ()
 			obj = m_Group->GetNextChild (j);
 		}
 		obj = m_Group->GetParent();
-		delete m_Group;
+		// deleting the group would delete the dialog as well, so...
+		g_idle_add ((GSourceFunc) delete_cb, m_Group);
 		obj->EmitSignal (gcp::OnChangedSignal);
 		m_Group = NULL;
 	}
